#!/usr/bin/env python3

import click

from . import aws

@click.group()
def ssm():
    pass

@ssm.command()
@click.argument('path')
def ls(path):
    aws.get_ssms(path)

@ssm.command()
@click.option('-r','--recursive',is_flag=True)
@click.option('-v','--value',is_flag=True)
@click.argument('key')
@click.argument('path')
def grep(path,key,recursive,value):
    aws.search_ssms(path,key,recursive,value)


if __name__ == '__main__':
    ssm()



from setuptools import setup, find_packages


with open('README.md') as f:
    readme = f.read()

with open('LICENSE') as f:
    license = f.read()

setup(
    name='ssmp',
    version='0.0.3',
    description='CLI tool for AWS SSM parameter',
    long_description_content_type='text/markdown',
    long_description=readme,
    author='Kevin Yi',
    author_email='yikaus@gmail.com',
    url='https://github.com/yikaus/ssmp',
    scripts=['ssmp/main.py'],
    license=license,
    packages=find_packages(exclude=('tests', 'docs')),
    install_requires=[
        'click',
        'boto3',
        'pandas',
    ],
    entry_points = {
        'console_scripts': [
            'ssmp = ssmp.main:ssm',
        ],
    }
)



import boto3
import pandas as pd


def get_ssms(path):

    client = boto3.client('ssm')
    data = client.get_parameters_by_path(
            Path=path,
            Recursive=False,
        )
    df=pd.DataFrame.from_dict(data['Parameters'])
    df['LastModifiedDate']=pd.to_datetime(df['LastModifiedDate']).dt.strftime("%y/%m/%d %H:%M")
    if df.empty == False:
        print(df[['Name','Type','Value','Version','LastModifiedDate']].to_string(index=False))

def search_ssms(path,key,recursive,value):

    client = boto3.client('ssm')
    data = client.get_parameters_by_path(
            Path=path,
            Recursive=recursive,
        )
    df=pd.DataFrame.from_dict(data['Parameters'])
    df['LastModifiedDate']=pd.to_datetime(df['LastModifiedDate']).dt.strftime("%y/%m/%d %H:%M")
    if value:
        result=df.loc[df['Value'].str.contains(key)]
    else:
        result=df.loc[df['Name'].str.contains(key)]

    if result.empty:
        print("Not found")
    else:
        print(result[['Name','Type','Value','Version','LastModifiedDate']].to_string(index=False))
